package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(``P`!````*J8$"#0````\H@```````#0`(``,
M`"@`'``;``8````T````-(`$"#2`!`B``0``@`$```0````$`````P```+0!
M``"T@00(M($$"!,````3````!`````$````!``````````"`!`@`@`0(7!$`
M`%P1```$`````!````$`````(````*`$"`"@!`A4+@``5"X```4`````$```
M`0````!0````T`0(`-`$"$!%``!`10``!``````0```!````R)X``,@N!0C(
M+@4(3`(``*P2```&`````!````(```#DG@``Y"X%".0N!0@8`0``&`$```8`
M```$````!````,@!``#(@00(R($$"$0```!$````!`````0```!0Y71D,(\`
M`#`/!0@P#P4(Y````.0````$````!````%'E=&0`````````````````````
M``````8````0````4N5T9,B>``#(+@4(R"X%"#@!```X`0``!`````$```"`
M%01E````````````````````````````*```!````"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!`````!````1TY5```````#`````@`````````$````%```
M``,```!'3E4`.)?NS%0"%4/A)QA>(`#*!ABE=^X1````/0````@````(````
M`!P0!"5`!((X`4`!H(8!B,`!``)+*`0H.*(R1XH`!`@]````/@```$$```!$
M````10```$P```!.````4````%0```!6`````````%@```!<````70```%X`
M`````````````'OP2FMNQ=\?SMY'+6M_FGPNQ9NVU&34?"'_Y`[9<5@<XD?&
M`;(!BV^L2^/`PN4_++KCDGSRV],=^Z%L8&H)0]:'^9R!9J_,9L6YG$`X\HL<
MQ(D%D$)%U>R)!W#3#!3BGLG5LG$R8MOMV\WCG@PZEPM6I)N66.CM[*?=HVM_
MJ9R;X:<""@J*$%>CX/M)`````````````````````.4!`````````````!(`
M``!7`@`````````````2````0@(`````````````$@```-@`````````````
M`!(```!?```````````````2````C@(`````````````$@```%\!````````
M`````!(```"``@`````````````2````$P``````````````(````$@"````
M`````````!(```"O`@`````````````2````W0(`````````````$@```"X#
M`````````````!(```#=`0`````````````2````'P$`````````````$@``
M`(```````````````!(````/`0`````````````2`````0$`````````````
M$@```!(#`````````````!(```#0`@`````````````2````O`$`````````
M````$@```/8!`````````````!(```!]`0`````````````2````W0``````
M````````$@```)P"`````````````!(````$`P`````````````2````IP(`
M````````````$@```"(``````````````!(```"\```````````````2````
M4```````````````$@```.0"`````````````!(```!L`@`````````````2
M````.P(`````````````$@```-L#`````````````!(```"@````````````
M```2````P`(`````````````$@```$$!`````````````!(````A`@``````
M```````2````UP$`````````````$@```#,!`````````````!(```!S`@``
M```````````2````=@$`````````````$@```.(``````````````!(````J
M`@`````````````2````>@(`````````````$@```&4"`````````````!(`
M``#'`@`````````````2````_`(`````````````$@```&L`````````````
M`!(```!J`0`````````````2````[@(`````````````$@```%`"````````
M`````!(````9`@`````````````2````T`$`````````````$@```"@!````
M`````````!(````P```````````````2````7@(`````````````$@````L#
M`````````````!(````4`@`````````````2````C@``````````````$@``
M`$\!````H@0(`````!(```#D`P``+\T$"&8````2``T`)@0``'*^!`C\"@``
M$@`-`!\#```@I`0("@(``!(`#0!.`P``&KD$"`4````2``T`@P,``&[)!`C!
M`P``$@`-`$P$```?N00(Q@$``!(`#0`5!```%#$%"``````0`!D`7P,``.6Z
M!`@?````$@`-`)D#```NO00(7@```!(`#0`%`@``!-`$"`0````1``\`_0,`
M`+ZW!`@T````$@`-`"$$``!T004(`````!``&0"(`0``T"X%"!,````1`!0`
M.@0``*R]!`C&````$@`-`/`#```$,04(`````!``&``_````$*($"``````2
M````O0,```2[!`BZ````$@`-`"0#```P,04(!````!$`&0"Y`@``*#$%"`0`
M```1`!D`)0,``#`Q!0@$````(0`9`#,$```4,04(`````!``&`!9!```$#$%
M"`0````1`!@`;`,``/C-!`@%````$@`-`.X```#`H`0(`````!(```#V`P``
M*J8$"``````2``T`!00``)7-!`AC````$@`-`/(#```$,04(`````"``&`#-
M````(#$%"`0````1`!D`?`,```#0!`@$````$0`/`"8#```P,04(!````"$`
M&0#)`P``C+T$""`````2``T`IP,``$NX!`C/````$@`-`*\```!`,04(`0``
M`!$`&0!C!```OKL$"'`!```2``T``&QI8G!E<FPN<V\N-2XR."XP`%]?9VUO
M;E]S=&%R=%]?`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K
M7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L
M:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!O<&5N-C0`8VQO
M<V4`;'-E96LV-`!?7V5R<FYO7VQO8V%T:6]N`')E860`;&EB8RYS;RXV`%])
M3U]S=&1I;E]U<V5D`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T
M9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D
M9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L
M:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8F-R>7!T+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L
M:6)C7V-S=5]F:6YI`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]D871A
M7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T87)T`%]E
M;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,RXT`$=,24)#7S(N,``O=7-R
M+VQI8B]P97)L-2\U+C(X+C`O:38X-BUP;&0M;&EN=7@M=&AR96%D+6UU;'1I
M+T-/4D4``````@`#``,```````0````$`````P`%``,`!@`'````````````
M`P`$``(``@````,`!0`#``,`````````!0`#``,``P````,````#``(````#
M``,````(``,``P`#``,```````0``P`#``<```````,``P`#```````!``$`
M`0`!``$``0`!``$``0`!``$``0````$``0````$``P`#``,``0`!``$````!
M``$``0````$``P`!``$````!`````0`%`/L!```0````8````!1I:0T```@`
M<`0``!````!R&6D)```&`'H$```0````$FEI#0``!0"&!```$````'09:0D`
M``0`D`0``!`````0:6D-```#`)P$`````````0`"`*P!```0`````````!)I
M:0T```<`A@0``!`````0:6D-```"`)P$````````_"\%"`8)``#0+@4(!4H`
M`"`Q!0@%60``*#$%"`50```P,04(!4\``$`Q!0@%7@``##`%"`<!```0,`4(
M!P(``!0P!0@'`P``&#`%"`<$```<,`4(!P4``"`P!0@'!@``)#`%"`<'```H
M,`4(!P@``"PP!0@'50``,#`%"`<*```T,`4(!PL``#@P!0@'#```/#`%"`<-
M``!`,`4(!PX``$0P!0@'#P``2#`%"`<0``!,,`4(!Q$``%`P!0@'$@``5#`%
M"`<3``!8,`4(!Q0``%PP!0@'%0``8#`%"`<6``!D,`4(!Q<``&@P!0@'&```
M;#`%"`<9``!P,`4(!QH``'0P!0@'&P``>#`%"`<<``!\,`4(!ST``(`P!0@'
M30``A#`%"`<=``"(,`4(!QX``(PP!0@''P``D#`%"`<@``"4,`4(!R$``)@P
M!0@'(@``G#`%"`<C``"@,`4(!R0``*0P!0@')0``J#`%"`<F``"L,`4(!R<`
M`+`P!0@'*```M#`%"`<I``"X,`4(!RH``+PP!0@'*P``P#`%"`<L``#$,`4(
M!RT``,@P!0@'+@``S#`%"`<O``#0,`4(!S```-0P!0@',0``V#`%"`<R``#<
M,`4(!S,``.`P!0@'-```Y#`%"`<U``#H,`4(!S8``.PP!0@'-P``\#`%"`<X
M``#T,`4(!SD``/@P!0@'.@``_#`%"`<[````,04(!SP`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[[4X/L".AC!@``@</SCP``BX/\____A<!T`O_0@\0(6\,`````````
M``````#_-00P!0C_)0@P!0@`````_R4,,`4(:`````#IX/____\E$#`%"&@(
M````Z=#_____)10P!0AH$````.G`_____R48,`4(:!@```#IL/____\E'#`%
M"&@@````Z:#_____)2`P!0AH*````.F0_____R4D,`4(:#````#I@/____\E
M*#`%"&@X````Z7#_____)2PP!0AH0````.E@_____R4P,`4(:$@```#I4/__
M__\E-#`%"&A0````Z4#_____)3@P!0AH6````.DP_____R4\,`4(:&````#I
M(/____\E0#`%"&AH````Z1#_____)40P!0AH<````.D`_____R5(,`4(:'@`
M``#I\/[___\E3#`%"&B`````Z>#^____)5`P!0AHB````.G0_O___R54,`4(
M:)````#IP/[___\E6#`%"&B8````Z;#^____)5PP!0AHH````.F@_O___R5@
M,`4(:*@```#ID/[___\E9#`%"&BP````Z8#^____)6@P!0AHN````.EP_O__
M_R5L,`4(:,````#I8/[___\E<#`%"&C(````Z5#^____)70P!0AHT````.E`
M_O___R5X,`4(:-@```#I,/[___\E?#`%"&C@````Z2#^____)8`P!0AHZ```
M`.D0_O___R6$,`4(:/````#I`/[___\EB#`%"&CX````Z?#]____)8PP!0AH
M``$``.G@_?___R60,`4(:`@!``#IT/W___\EE#`%"&@0`0``Z<#]____)9@P
M!0AH&`$``.FP_?___R6<,`4(:"`!``#IH/W___\EH#`%"&@H`0``Z9#]____
M):0P!0AH,`$``.F`_?___R6H,`4(:#@!``#I</W___\EK#`%"&A``0``Z6#]
M____);`P!0AH2`$``.E0_?___R6T,`4(:%`!``#I0/W___\EN#`%"&A8`0``
MZ3#]____);PP!0AH8`$``.D@_?___R7`,`4(:&@!``#I$/W___\EQ#`%"&AP
M`0``Z0#]____)<@P!0AH>`$``.GP_/___R7,,`4(:(`!``#IX/S___\ET#`%
M"&B(`0``Z=#\____)=0P!0AHD`$``.G`_/___R78,`4(:)@!``#IL/S___\E
MW#`%"&B@`0``Z:#\____)>`P!0AHJ`$``.F0_/___R7D,`4(:+`!``#I@/S_
M__\EZ#`%"&BX`0``Z7#\____)>PP!0AHP`$``.E@_/___R7P,`4(:,@!``#I
M4/S___\E]#`%"&C0`0``Z4#\____)?@P!0AHV`$``.DP_/___R7\,`4(:.`!
M``#I(/S___\E`#$%"&CH`0``Z1#\__]5B>575E.#Y/"#[$"+10R)1"0LBT40
MB40D*&6A%````(E$)#PQP(U$)"B)1"0(C40D+(E$)`2-10B)!"3H;____\=$
M)`C`H`0(QT0D!,"@!`C'!"00H@0(Z(`I``"`/4`Q!0@`=2[H%?W__Z-P004(
MA<`/A($!``")!"3HD/W__Z$@,04(B00DZ-/\___&@#T&````H2`Q!0B)!"3H
MO_S__X"(G@(```*A(#$%"(D$).BK_/__@(B>`@```8M%"(/`!3W___\_#X<8
M`0```<`!P(D$).AW_O__HV1!!0B+7"0LBQ.)$,=`!,W1!`B+%1`Q!0B)4`C'
M0`S0T00(QP5H004(!````(MU"(/^`7X;C5,$C4@0C3PV`?\!^XLZB3F#P@2#
MP00YTW7RQT2P#`````#'1"00`````(E$)`R#Q@.)="0(QT0D!/*W!`BA<$$%
M"(D$).@F^___B<.%P'1(H7!!!0B)!"3H0_W__XU4)#BXJ-`$".B$#```A<!T
M.J%P004(B00DZ,3Z___H/_S__XG8BW0D/&4S-10```!U98UE]%M>7UW#H7!!
M!0B)!"3H2_O__XG#ZZ>A;$$%"(7`=`J)!"3H12<``.NSC50D.+A=T`0(Z"4,
M``"C;$$%"(7`=)SKW<=$)`30+@4(QP0D6M`$".A'_?__QP0D`0```.C;_?__
MZ.;\__\Q[5Z)X8/D\%!44N@C````@</&B0``C8/XG?__4(V#E9W__U!15L?`
M(*0$"%#H!/O___2+'"3#\P\>^\-FD&:09I!FD&:0BQPDP[@4,04(/10Q!0AT
M&K@`````A<!T$56)Y8/L&,<$)!0Q!0C_T,G#P[@4,04(+10Q!0C!^`*)PL'J
M'P'0T?AT'KH`````A=)T%56)Y8/L&(E$)`3'!"04,04(_]+)P\.`/4$Q!0@`
M=115B>6#[`CHCO___\8%03$%"`')P\/KJ6:09I!FD&:09I!FD&:055=64X'L
M?`$``(G!B40D"&6A%````(F$)&P!```QP(M4@1P/RHE4A"R#P`&#^!!U[HU4
M)"R-C"0L`0``BT(T,T(@,T((,P+1P(E"0(/"!#G*=>F+?"0(BQ^+=P2+;PB+
M3PR+1Q")1"0<`T0D+(V0F7F"6HG8P<`%`<*)Z#'((?")SS'(`=")="00B?+!
MR@*)Z3'1B=XAV3'IB7PD&(M<)#`!^X'#F7F"6@'+B<'!P04!RXET)`S!S@*)
MT3'Q(<$QT8EL)!0#;"0TB>^!QYEY@EH!^8G=P<4%`>G!R`*)]3'%B>\AWS'W
M`U0D.('"F7F"6@'ZB<W!Q04!ZL'+`HG%,=V)[R'/,<<#="0\@<:9>8):`?Z)
MU<'%!0'NP<D"B=TQS8GO(=<QWP-$)$`%F7F"6@'XB?7!Q04!Z,'*`HG-,=6)
M[R'W,<\#7"1$@<.9>8):`?N)Q<'%!0'KP<X"B=4Q]8GO(<<QUP-,)$B!P9EY
M@EH!^8G=P<4%`>G!R`*)]3'%B>\AWS'W`U0D3('"F7F"6@'ZB<W!Q04!ZL'+
M`HG%,=V)[R'/,<<#="10@<:9>8):`?Z)U<'%!0'NP<D"B=TQS8GO(=<QWP-$
M)%0%F7F"6@'XB?7!Q04!Z,'*`HG-,=6)[R'W,<\#7"18@<.9>8):`?N)Q<'%
M!0'KP<X"B=4Q]8GO(<<QUP-,)%R!P9EY@EH!^8G=P<4%`>G!R`*)]3'%B>\A
MWS'W`U0D8('"F7F"6@'ZB<W!Q04!ZL'+`HG%,=V)[R'/,<<#="1D@<:9>8):
M`?Z)U<'%!0'NP<D"B=TQS8GO(=<QWP-$)&@%F7F"6@'XB?7!Q04!Z,'*`HG-
M,=6)[R'W,<\#7"1L@<.9>8):`?N)Q<'%!0'KP<X"B=4Q]8GO(<<QUP-,)'"!
MP9EY@EH!^8G=P<4%`>G!R`*)]3'%B>\AWS'W`U0D=('"F7F"6@'ZB<W!Q04!
MZL'+`HG%,=V)[R'/,<<#="1X@<:9>8):`?>)U<'%!0'OP<D"`T0D?`6AZ]EN
MB=TQS8GN,=8!QHGXP<`%`<;!R@(#G"2`````C8.AZ]ENB<LQTS'[`<.)\,'`
M!0'#B?C!R`(#C"2$````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DB```
M`(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$)(P```"-N*'KV6Z)\#'8,<@!
M^(G5P<4%`>C!R0(#M"20````C;ZAZ]ENB=TQS8GN,=8!_HG%P<4%`>[!R@(#
MG"24````C;NAZ]ENB<LQTS'#`?N)]<'%!0'KP<@"`XPDF````(VYH>O9;HG1
M,<$Q\0'YB=W!Q04!Z<'.`@.4))P```"-NJ'KV6Z)PC'R,=H!^HG-P<4%`>K!
MRP(#A"2@````C;BAZ]ENB?`QV#'(`?B)U<'%!0'HP<D"`[0DI````(V^H>O9
M;HG=,<V)[C'6`?Z)Q<'%!0'NP<H"`YPDJ````(V[H>O9;HG+,=,QPP'[B?7!
MQ04!Z\'(`@.,)*P```"-N:'KV6Z)T3'!,?$!^8G=P<4%`>G!S@(#E"2P````
MC;JAZ]ENB<(Q\C':`?J)S<'%!0'JP<L"`X0DM````(VXH>O9;HGP,=@QR`'X
MB=7!Q04!Z,')`@.T)+@```"-OJ'KV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<
M)+P```"-NZ'KV6Z)RS'3,<,!^XGUP<4%`>O!R`(#C"3`````C;FAZ]ENB=$Q
MP3'Q`?F)W<'%!0'IP<X"`Y0DQ````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+
M`@.$),@```"-N*'KV6Z)\#'8,<@!^(G5P<4%`>C!R0*)W0G-(=6)WR'/">\#
MM"3,````@>XD0^1P`?>)Q<'%!0'OP<H"B<T)U2'%B<XAU@GN`YPDT````('K
M)$/D<`'>B?O!PP4!WL'(`HG3"<.)W2']B=,APPGK`XPDU````('I)$/D<`'+
MB?'!P04!R\'/`HG!"?F)S2'UB<$A^0GI`Y0DV````('J)$/D<`'1B=K!P@4!
MT<'.`HGZ"?*)U2'=B?HA\@GJ`X0DW````"TD0^1P`<*)R,'`!0'"P<L"B?4)
MW2'-B?`AV`GH`[PDX````('O)$/D<`'XB=7!Q04!Z,')`HG="<TAU8G?(<\)
M[P.T).0```"![B1#Y'`!_HG%P<4%`>[!R@*)S0G5(<6)SR'7">\#G"3H````
M@>LD0^1P`?N)]<'%!0'KP<@"B=4)Q2'UB=<AQPGO`XPD[````('I)$/D<`'Y
MB=W!Q04!Z<'.`HG%"?4AW8G'(?<)[P.4)/````"!ZB1#Y'`!^HG-P<4%`>K!
MRP*)]0G=(<V)]R'?">\#A"3T````+21#Y'`!^(G5P<4%`>C!R0*)W0G-(=6)
MWR'/">\#M"3X````@>XD0^1P`?Z)Q<'%!0'NP<H"B<T)U2'%B<\AUPGO`YPD
M_````('K)$/D<`'[B?7!Q04!Z\'(`HG5"<4A]8G7(<<)[P.,)``!``"!Z21#
MY'`!^8G=P<4%`>G!S@*)Q0GU(=V)QR'W">\#E"0$`0``@>HD0^1P`?J)S<'%
M!0'JP<L"B?4)W2'-B?<AWPGO`X0D"`$``"TD0^1P`<>)T,'`!0'XP<D"B=T)
MS2'5B=\ASPGO`[0D#`$``('N)$/D<`'^B<7!Q04![L'*`HG-"=4AQ8G/(=<)
M[P.<)!`!``"!ZR1#Y'`!WXGSP<,%`?O!R`*)U0G%(?6)UR''">\#C"04`0``
M@>DD0^1P`<^)V<'!!0'YP<X"B<4)]2'=B<<A]PGO`Y0D&`$``('J)$/D<`'7
MB<K!P@4!^L'+`@.$)!P!```M*CZ=-8GU,=V)[S'/`<>)T,'`!0''P<D"`[0D
M(`$``('N*CZ=-8G8,<@QT`'PB?W!Q04!Z,'*`HG6`YPD)`$``(V3UL%BRHG+
M,?,Q^P'3B<+!P@4!T\'/`@.,)"@!``"!Z2H^G36)\C'Z,<(!RHG9P<$%`<J)
MP<')`@.T)"P!``"-AM;!8LJ)_3'-B>XQW@'&B=#!P`4!QL'+`@.\)#`!``"!
M[RH^G36)R#'8,=`!^(GUP<4%`>C!R@*)UP.,)#0!``"-D=;!8LJ)V3'Y,?$!
MT8G"P<(%`='!S@(#G"0X`0``@>LJ/ITUB?HQ\C'"`=J)R\'#!0':B</!RP(#
MO"0\`0``C8?6P6+*B?4QW8GO,<\!QXG0P<`%`<?!R0(#M"1``0``@>XJ/ITU
MB=@QR#'0`?")_<'%!0'HP<H"B=8#G"1$`0``C9/6P6+*B<LQ\S'[`=.)PL'"
M!0'3P<\"`XPD2`$``('I*CZ=-8GR,?HQP@'*B=G!P04!RHG!P<D"`[0D3`$`
M`(V&UL%BRHG],<V)[C'>`<:)T,'`!0'&P<L"`[PD4`$``('O*CZ=-8G(,=@Q
MT`'XB?7!Q04!Z,'*`@.,)%0!``"!Z2H^G36)W3'5B>\Q]P'/B<'!P04!S\'.
M`@.<)%@!``"!ZRH^G36)T3'Q,<$!V8G[P<,%`=G!R`(#E"1<`0``@>HJ/ITU
MB?,QPS'[`=.)RL'"!0'3P<\"`[0D8`$``('N*CZ=-8G",?HQR@'RB=W!Q04!
MZL')`@.$)&0!``"-L-;!8LJ)^#'(,=@!\(G5P<4%`>C!RP*+="0,`[0D:`$`
M`('N*CZ=-0'WB<XQWC'6`?Z)Q<'%!0'NBWPD"(DW`T0D$(E'!,'*`HML)!2-
M!"J)1P@#7"08B5\,`TPD'(E/$(N$)&P!``!E,P44````=0N!Q'P!``!;7E]=
MP^CQ\/__55=64X/L+(7`#X22````BPTP,04(B4PD&(7)#X2`````#[8(A,ET
M!8#Y/74_,>V+?"08BQ^%VW0IB50D'(G&B6PD"(ET)`2)'"3H,O'__X7`=0:`
M/"L]="J#QP2+'X7;==V)V(/$+%M>7UW#B<&#P0$/MAF$VW0%@/L]=?$IP8G-
MZZR)^BM4)!C!^@*+1"0<B1"-30$!RXG8@\0L6UY?7<,QVXG8@\0L6UY?7<-3
M@^P8B<-EH10```")1"0,,<"-5"0(B=CH-O___X7`=#*+1"0(`<`!P`,%,#$%
M"(M0!(D0A=)TVH/`!(M0!(D0A=)U](U4)`B)V.@$____A<!USHM$)`QE,P44
M````=06#Q!A;P^C:[___55=64X/L/(G'B=-EH10```")1"0L,<"`.CUU`X/#
M`8D<).CS[O__B<6-5"0HB?CHM?[__XG&A<`/A-8```")!"3HU.[__SGH#X.T
M````BT0D*`'``<")1"08#[8'A,`/A%H!```\/0^$4@$``(GX@\`!#[80A-)T
M!8#Z/77Q*?B+="08`S4P,04(@\4"`>B)!"3H(^___XD&A<`/A#$!``"+5"0H
MH3`Q!0B+%)"-3P$/M@>(`CP]=!J$P'4&ZQ0\/700@\(!@\$!#[9!_X@"A,!U
M[,8"/3'`#[8,`XA,`@&#P`&$R77Q,<"+?"0L93,]%`````^%X@```(/$/%M>
M7UW#,<`/MA0#B!0&@\`!A-)U\NO3BQ4P,04(BS*%]@^$H@```#'`ZP*)\(UP
M`8L,LH7)=?2#P`,!P`'`BPU@004(A<EU6(E4)!S'!6!!!0@!````B00DZ%_N
M__^)P87`='&-!#8!P(E$)!B)1"0(BU0D'(E4)`2)#"2)3"0<Z)CN__^+3"0<
MB0TP,04(QT2Q!`````")="0HZ;W^__^)1"0$B10DZ/'K__^)P:,P,04(A<!T
M'HT$-@'`B40D&.O-,<#INO[__[@(````,?;I:?___[C_____Z0W____H^>W_
M_U575E.![*P```")PV6A%````(F$))P````QP(7;=`6`.P!U'XN$))P```!E
M,P44````#X4:`0``@<2L````6UY?7<.)'"3H?NS__XG%A<!TTXDL).C0[/__
MA<`/A-,```"-4!._"=`$"+D"````B=;SI@^7P!P`A,!TUK\(T`0(N0,```")
MUO.F#Y?`'`"$P'2_B50D+(D<).B;[/__B<:+5"0LB10DZ(WL__\!QH/&`HDT
M).@@[?__B<:+5"0LB50D%(E<)!#'1"0,"]`$",=$)`C_____QT0D!`$```")
M!"3H@NW__XU$)#R)1"0(B70D!,<$)`,```#HRNK__X/X_W00BT0D3"4`\```
M/0!```!T-8DT).@M[/__B30DZ'7K__^)+"3H_>O__X7`#X4M____B2PDZ%WL
M__^)'"3HQ>S__^G;_O__B?#HL/[__^O*Z*+L__]3@>R(````B<-EH10```")
M1"1\,<"-1"0<B40D"(E<)`3'!"0#````Z"7K__^%P'4TBU0D+('B`/```('Z
M`$```'0(@?H`H```=1S'1"0$`@```(D<).@'Z___A<`/E,`/ML#K`C'`BTPD
M?&4S#10```!U"('$B````%O#Z"'L__]55U93@>P\$```B<>)5"0<9:$4````
MB80D+!```#'`QT0D"/\/``"-7"0LB5PD!,<$)!'0!`CH%NS__X7`?F>-</^+
M+2`Q!0B`?#0L`'53A?9T68ET)`C'1"0$+P```(D<).@Z[/__A<!T08DL).@>
MZO__B70D#(E<)`B)?"0$B00DZ`KK__^+A"0L$```93,%%````'4S@<0\$```
M6UY?7<.)QNNMBRT@,04(B2PDZ-WI__^+3"0<B4PD"(E\)`2)!"3HF>G__^N]
MZ%+K__^#[!RA(#$%"(D$).BRZ?__QT0D#/C1!`C'1"0(`*($",=$)`0@T`0(
MB00DZ-+K__^#Q!S#@^PLH2`Q!0B)!"3H?NG__XD$).BT____H2`Q!0B)!"3H
M:>G__\=$)!0`````QT0D$*K1!`C'1"0,JM$$",=$)`ANR00(QT0D!#S0!`B)
M!"3HV>G__X/$+,-75E.![#`@``!EH10```")A"0L(```,<#HZ.?__\=$)!0<
MT`0(B40D$,=$)`Q1T`0(QT0D"`$0``#'1"0$`0```(U<)"J)'"3HZ.K__\=$
M)`@`$```C;0D*Q```(ET)`2)'"3HC>K__X7`>%J)PXU``8D$).@LZO__A<!T
M%8G'@_L$<S3VPP)U)O;#`74>Q@08`(N4)"P@``!E,Q44````=2B!Q#`@``!;
M7E_#I.O?9J7VPP%TV.OTB=G!Z0+SI?;#`G3%Z^DQP.O(Z/;I___I+/___U57
M5E.![*P0``"+K"3`$```B[0DQ!```&6A%````(F$))P0```QP(U4)#RX7=`$
M".C+^/__B</'1"0$+P```(DL).B*Y___A<!T+8GJN&;0!`CHP/G__XGHBXPD
MG!```&4S#10````/A50!``"!Q*P0``!;7E]=PXDL).BQZ/__B<?'1"0$<]`$
M"(DT).A_Z?__B<:-1P&)1"0LA?9TK(`^``^$P@```(7;=!2)="0$B1PDZ!GJ
M__^%P`^$CP```(DT).AIZ/__@'P&_R]U#H/H`<8$!@"`?`;_+W3R`T0D+#W_
M#P``#X]?____B6PD&,=$)!1UT`0(B70D$,=$)`Q@T00(QT0D"``0``#'1"0$
M`0```(VT))P```")-"3H/NG__XU$)#R)1"0(B70D!,<$)`,```#HAN;__X7`
M=1"+1"1,)0#P```]`(```'1%QT0D!'/0!`C'!"0`````Z*[H__^)QNDQ____
MA=MT%[D"````B=Z_"=`$"/.F#Y?`'`"$P'3*O@G0!`BX`0```.E)____QT0D
M!`$```")-"3H#>?__X7`=:>)\KAFT`0(Z&/X__^)-"3H!>G__^F8_O__Z"OH
M__^+5"0$#[8*B="$R701@\(!@/DO#T3"#[8*A,EU\,/#4X/L&(M<)""%VP^$
MD@```(`[``^$B0```(D<).@KY___@^@!`=@YPW()ZQJ#Z`$YPW07@#@O=/3K
M!8`X+W0F@^@!.<-R]#G#=1N`."]T4\=$)"!UT`0(@\086^E\Z/__@#@O=0>#
MZ`$YPW+T*=B-4`*!^@`0``!W.L=$)`P`$```@\`!B40D"(E<)`3'!"1@,04(
MZ/3D__^X8#$%"(/$&%O#QT0D(`G0!`B#Q!A;Z2GH__\QP(/$&%O#5U:#[#1E
MH10```")1"0L,<`/MP74T00(9HE$)`J-?"0,OM;1!`BX(````(G!P>D"\Z6H
M`G0"9J6X=]`$".C,]O__N(#0!`CHPO;__[B(T`0(Z+CV__^XD=`$".BN]O__
MN)C0!`CHI/;__[BHT`0(Z)KV__^X7=`$".B0]O__N+30!`CHAO;__[B^T`0(
MZ'SV__^XR-`$".AR]O__N&;0!`CH:/;__XU4)`2XTM`$".BM]?__A<!T#(G"
MN+[0!`CHM/;__XU4)`2XX]`$".B/]?__A<!T#(G"N/70!`CHEO;__XU4)`2X
M`-$$".AQ]?__A<!T+HG"N%W0!`CH>/;__[HLT00(N)C0!`CH:?;__XM$)"QE
M,P44````=4^#Q#1>7\.-5"0$N!#1!`CH,?7__X7`=`Z)PKBTT`0(Z#CV___K
MOHUT)!N_(=$$"+D*````\Z8/E\`<`(3`=:6-5"0EN+30!`CH#_;__^N5Z.+E
M__^#[!QEH10```")1"0,,<"A##$%"(/X_W01BTPD#&4S#10```!U,X/$',.-
M5"0(N+30!`CHN?3__X7`=!D/MA"`^C`/E<$QP(32#Y7`(<BC##$%".O$,<#K
M]>B$Y?__@^P<Z/SD__^)!"3HU.3__X7`=`:+`(/$',,QP(/$',-75E.#[#"+
M="1`9:$4````B40D+#'`C50D*+BJT00(Z$_T__^%P'0'B<.`.`!U((GRN*K1
M!`CH3_7__XM$)"QE,P44````=7F#Q#!;7E_#B70D!(D$).C9Y/__A<!UW(DT
M).@]Y/__B<>)'"3H,^3__P''@\<"B3PDZ,;D__^)QXE<)!C'1"04<]`$"(ET
M)!#'1"0,8-$$",=$)`C_____QT0D!`$```")!"3H).7__XGZN*K1!`CHSO3_
M_^EZ____Z)[D__]55U93@>R<@0``BX0DL($``(E$)$1EH10```")A"2,@0``
M,<#'A"2\````.M$$",>$),`````)T`0(QX0DQ`````````#'A"34````]=`$
M",>$)-@```#NT`0(QX0DW````#_1!`C'A"3@````"]$$",>$).0```!'T00(
MQX0DZ`````````#'A"3(````+M$$",>$),P```!+T00(QX0DT`````````"-
M5"1<N%W0!`CH]_+__X7`=`F`.``/A9($``#H4O[__XG&A<`/A`,$``")-"3H
M!./__P'`@\`!B00DZ)?C__^)PX`^`'0TB=\/M@:)1"00QT0D#%31!`C'1"0(
M_____\=$)`0!````B3PDZ/?C__^#Q@&#QP*`/@!USHVT)-@```"X]=`$".L.
M@\8$BT;\A<`/A(H!``"-5"1<Z&;R__^)QX7`=..`.`!TWNBE]O__A<!TU8D\
M).@+Y/__B<>%P`^$6P$``(G^BQ:#Q@2-@O_^_O[WTB'0)8"`@(!TZHG"P>H0
MJ8"````/1,*-5@(/1/*)P0#!@]X#*?Z)VHL*@\($C8'__O[^]]$AR"6`@("`
M=.J)P<'I$*F`@```#T3!C4H"#T31B<$`P8/:`RG:`=:!Q@0$``")-"3HF>+_
M_XE$)#R)7"0<QT0D&%G1!`C'1"04==`$"(E\)!#'1"0,7M$$",=$)`C_____
MQT0D!`$```")PXD$).CKXO__QT0D!,`!``")'"3HN]___X/X_W40Z)'?__^+
M`(/X$0^%S0(``(U$)%R)1"0(BT0D/(E$)`3'!"0#````Z.K@__^)PX7`#X25
M````BT0D/(E$)!"+1"1$BP")1"0,QT0D"$#2!`C'1"0$`0```*$H,04(B00D
MZ*'?___'1"1``````(M$)$"+C"2,@0``93,-%`````^%.@@``('$G($``%M>
M7UW#,>V+M*R\````A?9T)H`^`'0AB?#H&_7__X/%`87`=.*)-"3H?N+__X7`
M=-:)Q^ER_O__,?^0Z6K^__^+1"1L)0#P```]`$````^%5____XM\)'3H_N#_
M_SG'#X5&____BT0D;"7_`0``/<`!```/A3+___^)-"3H.N'__XE$)$"-5"1<
MN&?1!`CH5_#__X7`#X0P`@``B00DZ`CB__^)1"0$BT0D1(L`B00DZ#7W__^)
MPH7`#X0,`@``B10DB50D2.A0X/__@_@#BU0D2'8OC7#\`=:_;-$$"+D%````
M\Z8/E\&`V0"$R744@_@$#X3"!0``@'P"^R\/A+<%``")5"1$Z.WZ__^%P'4@
MQT0D!`````"+5"1$B10DZ%?A__^)1"1(A<`/A:8!``"Z+-$$"+BTT`0(Z,+P
M___HU]W__\=$)!RJT00(B40D&,=$)!1UT`0(BWPD/(E\)!#'1"0,A=$$",=$
M)`C_____QT0D!`$```"+="1`B30DZ,?@___K3NB`W?__@S@1=5F#PP'H@]W_
M_\=$)""JT00(B5PD'(E$)!C'1"04==`$"(E\)!#'1"0,D]$$",=$)`C_____
MQT0D!`$```")-"3H=^#__\=$)`3``0``B30DZ$?=__^#^/]TG8M$)#R)!"3H
MAM[__XM<)$")VKA=T`0(Z/SO__^)'"3H:OK__^G0_?__N"[1!`@QV^L'BX2<
MR````(7`#X2)````C50D7.BW[O__@\,!A<!TX8`X`'3<B00DZ&3@__^%P'30
MB<;IO?O__XE$)!2+1"0\B40D$(M$)$2+`(E$)`S'1"0(!-($",=$)`0!````
MH2@Q!0B)!"3H]MS__\=$)$``````Z5#]__^)!"2)1"0\Z-GY__^+1"0\B00D
MZ`'@__^)1"1`Z2_]___'!"0-````Z/S>__^)P[XST00(Z6#[__^+1"1$BQ#I
MZ?W__\=$)`P"````QT0D!.[____'1"0(_____XG#B00DZ./<___'1"0(!@``
M`(V$)(P!``")1"0$B1PDZ$C=__^`O"2,`0```'4.@+PDC0$``$,/A`@$``#'
M1"0,`````,=$)`0`````QT0D"`````"+1"1(B00DZ(S<___'A"3L`````2-%
M9\>$)/````")J\WOQX0D]````/[<NIC'A"3X````=E0R$,>$)/P```#PX=+#
MQX0D``$```````#'A"0$`0```````,>$)$@!````````QT0D"`"```"-A"2,
M`0``B40D!(M$)$B)!"3HE=S__XG%A<`/CF@!``"-1"T``<`!P#')`X0D``$`
M``^2P8N4)`0!``"#^0&#VO^)A"0``0``B>C!Z!T!T(F$)`0!``"+E"1(`0``
MA=(/A/(```"X0````"G0.<4/3L6-C"0(`0```=&)PHG/C;0DC`$``(/X!`^#
MV0```/;"`G0"9J6#X@%T`:2+E"1(`0```<*)E"1(`0``@_I`#X5#____*<6-
MC"2,`0```<B)1"1$C80D[````.A,X?__@_T_?E2+3"1$B<N-1<")1"1,B<6#
MY<"-04`!Q;D0````C;PD"`$``(G>\Z6-A"3L````Z!3A__^#PT`YW77=BTPD
M3(G(P>@&C5`!P>(&`50D1,'@!BG!B<W'1"0,1````(EL)`B+1"1$B40D!(V$
M)`@!``")!"3H0-O__XFL)$@!``#IH/[__XV$)(P!``")1"1$Z6C____VP0$/
MA><"``#WQP(````/A<<"``")T<'I`O.EZ0;___^+1"1(B00DZ$?<__^+A"0`
M`0``B<8/SHN<)`0!```/R\'H`X/@/XU(`<:$!`@!``"`@_DX#XZ2`0``N$``
M``"-O"0(`0``C10/*<B)P70-,<#&!`(`@\`!.<AR]8V$).P```#H*^#__[D.
M````,<"-O"0(`0``\ZN)G"1``0``B;0D1`$``(V$).P```#H`>#__XN$).P`
M``")P@_*P>@8B90D3P$``(N4)/`````/RHF4)%,!``"+E"3T````#\J)E"17
M`0``BY0D^`````_*B90D6P$``(N4)/P````/RHF4)%\!``"-M"1C`0``B?>-
MK"10`0``C9PDBP$``.L'#[9%`(/%`0^VP(E$)!#'1"0,5-$$",=$)`C_____
MQT0D!`$```")/"3HY=O__X/'`CG[=<O&A"2+`0```,=$)!RJT00(B70D&,=$
M)!1UT`0(BT0D/(E$)!#'1"0,=M$$",=$)`C_____QT0D!`$```"+1"1`B00D
MZ);;___I+_O__XM$)$2+:`2%[0^$.OK__XE4)$2)+"3H1MK__X/X`XM4)$0/
MAB'Z__^#Z`2-=`4`OW'1!`BY!0```/.F#Y?`'`"$P`]$U>G_^?__NC@````I
MRHV\#`@!```QP(/Z!`^#I0```/;"`G0"9JN#X@$/A(/^__^JZ7W^__^`O"2.
M`0``00^%ZOO__X"\)(\!``!##X7<^___@+PDD`$``$@/A<[[__^`O"21`0``
M10^%P/O__\=$)`P"````QT0D!,;____'1"0(_____XM<)$B)'"3H3-C__\=$
M)`@I````C80DC`$``(E$)`2)'"3HL=C__\=$)!RJT00(C80DC`$``(E$)!CI
MO_[___?'`0```'5D]\<"````=56#^@0/@D+___^)U8/E_#')B00/@\$$.>ER
M]@'/Z2K___\/MPYFB0^#QP*#Q@*#Z@+I)?W__P^VG"2,`0``B%PD1(@9@\<!
MC;0DC0$``(U0_^GY_/__9JN#Z@+KI*J#Z@'KENBBV?__55=64X/L+&6A%```
M`(E$)!PQP*$@,04(B00DZ/+7__^)PZ$@,04(B00DZ./7__\/MDMDB$AEC50D
M&+B8T`0(Z&WH__^%P'0)@#@Q#X3X`@``D.CY\?__H2`Q!0B)!"3HKM?__\=$
M)`P+````QT0D"`$```#'1"0$I-$$"(D$).A.U___A<`/A,````"+0`R+>!B+
M-2`Q!0B#/6A!!0@!#XZM````,=OK-8M%#(E$)`2-:P&A9$$%"(L$J(D$).B_
MV?__BQ5H004(A<`/A0T"``"#PP(YVHGK#XX``@``B30DZ"S7___'1"0,````
M`(E<)`B)?"0$B00DZ#38__^%P`^$S`$``(LHBS4@,04(BT4()0`$(``]``0`
M`'2,B30DZ.W6___'1"0,`@```,=$)`@`````B6PD!(D$).AAV?__BS4@,04(
MZ6#___^+-2`Q!0B)-"3HN-;__\=$)`P#````QT0D"`$```#'1"0$J=$$"(D$
M).A8UO__B<.%P'0UBT`,BS"A(#$%"(D$).B`UO__QT0D"*O1!`B)="0$B00D
MZ#S6__^+0PR+&/9#"D`/A<H!``"A(#$%"(D$).A0UO__QT0D#`,```#'1"0(
M`0```,=$)`2PT00(B00DZ/#5__^)PX7`=#J-5"08N&;0!`CHN^;__XG&A<`/
MA%@!``"+0PR+&*$@,04(B00DZ`#6__^)="0(B5PD!(D$).C`U?__H2`Q!0B)
M!"3HX]7__\=$)`@!````QT0D!++1!`B)!"3HR]3__XG#H2`Q!0B)!"3HO-7_
M_\=$)`C'T00(B5PD!(D$).AXU?__H2`Q!0B)!"3HF]7__\9`90"-5"08N%W0
M!`CH*.;__XG#HVQ!!0B%P`^$B0```,=$)`3``0``B1PDZ$K4__^-4`&#^@%V
M"8/X$0^%Z0```(M$)!QE,P44````#X73````@\0L6UY?7<.+%6A!!0B+-2`Q
M!0B-0O\YV`^%:?[__X/Z`0^.8/[__[L!````B30DZ!/5__^)?"0$B00DZ+?4
M__^#PP&+-2`Q!0@Y'6A!!0A_V^DQ_O__H61!!0B)!"3HUO'__XG#HVQ!!0B%
MP`^%6____\<$))32!`CHJ=;__X!X`0`/A`3]___I^?S__Z%D004(BS"+0PR+
M&*$@,04(B00DZ*'4__^)\HG8Z`?J___IH_[__Z$@,04(B00DZ(;4__^)7"0$
MB00DZ/K5___I&/[__^@`UO__B40D#(E<)`BA9$$%"(L`B40D!,<$)+C2!`CH
M,=;__U=64X/L$(M<)"")'"3HP^W__P^V$(G&A-)T$(/``8#Z+P]$\`^V$(32
M=?#HS^___X7;=!Z%P'0:@#L`=!6_6=$$"+D$````\Z8/E\`<`(3`=`>#Q!!;
M7E_#B=B#Q!!;7E_I@N?___,/'OM55U93@^PLZ,O8__^!PUMB``"+?"1$BVPD
M2.A(TO__C8/,_O__C9/(_O__*=#!^`*)1"0<="$Q]HEL)`B)?"0$BT0D0(D$
M)/^4L\C^__^#Q@$Y="0<=>&#Q"Q;7E]=P_,/'OO#\P\>^U.#[!CH9MC__X'#
M]F$``(N#"`$``(E$)`R+1"0HB40D"(M$)"2)1"0$BT0D((D$).C*TO__@\08
M6\,`\P\>^U.#[`CH)]C__X'#MV$``(/$"%O#````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O
M8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`%5315(`4UE3
M5$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E
M<R5S`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#0U`"UE`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[X````!L`````D?__$`$`
M`/"4__]L!0``,9?___P```#0E___-`$``.^B__]X`0``G*/__^`!```&I/__
M!`(``.>E__]$`@``/J?__X0"``"_I___K`(``(ZH___L`@``PJC__P0#```;
MJ?__'`,``.JI__]4`P``[ZG__V@#``"UJ___J`,``-2K__^\`P``CJS___P#
M``#^K?__+`0``%RN__](!```?*[__V@$``!"K___H`0``#ZZ___D!```_[W_
M_R0%``!EOO__G`4``,B^___8!0``S;[__^P%```4``````````%Z4@`!?`@!
M&PP$!(@!```0````'````"V6__\%`````````"`````P````Z(____`#````
M#@A&#@Q*#PMT!'@`/QH[*C(D(D````!4````E);__Q\+````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#I`#`PL+"@X40<,.$$'&#@Q!QPX(0<4.!$$+````9```
M`)@```!OH?__K0````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.0`)@"@X40<,.
M$$'&#@Q!QPX(0<4.!$$+<`H.%$'##A!!Q@X,0<<."$'%#@1!"T<.%$'##A!!
MQ@X,0<<."$'%#@0@``````$``+2A__]J`````$$."(,"0PX@`E\*#@A!PPX$
M00L\````)`$``/JA___A`0```$$."(4"00X,AP-!#A"&!$$.%(,%0PY0`O8*
M#A1!PPX00<8.#$''#@A!Q0X$00L`/````&0!``";H___5P$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!48.P`%T"@X40<,.$$'&#@Q!QPX(0<4.!$$+`"0```"D
M`0``LJ3__X$`````00X(@P)&#I`!`G,*#@A!PPX$00L````\````S`$```NE
M___/`````$$."(4"00X,AP-!#A"&!$$.%(,%1@[0(`*3"@X40<,.$$'&#@Q!
MQPX(0<4.!$$+%`````P"``":I?__-`````!##B!P#@0`%````"0"``"VI?__
M60````!##C`"50X$-````#P"``#WI?__SP````!!#@B'`D$.#(8#00X0@P1&
M#L!``I\*#A!!PPX,0<8."$''#@1!"P`0````=`(``(ZF__\%`````````#P`
M``"(`@``?Z;__\8!````00X(A0)!#@R'`T$.$(8$00X4@P5&#L`A`FD*#A1!
MPPX00<8.#$''#@A!Q0X$00L0````R`(```6H__\?`````````#P```#<`@``
M$*C__[H`````00X(@P)##B`"5@H."$'##@1%"P)`"@X(0<,.!$$+2PH."$'#
M#@1%"T4."$'##@0L````'`,``(JH__]P`0```$$."(<"00X,A@-##D`#&@$*
M#@Q!Q@X(0<<.!$$+```8````3`,``,JI__]>`````$,.(&8*#@1!"P``'```
M`&@#```,JO__(`````!##B!6"@X$00M%#@0````T````B`,```RJ___&````
M`$$."(<"00X,A@-!#A"#!$,.0`)%"@X00<,.#$'&#@A!QPX$00L``$````#`
M`P``FJK___P*````00X(A0)!#@R'`T$.$(8$00X4@P5&#K"#`@.Y`@H.%$'#
M#A!!Q@X,0<<."$'%#@1!"P``/`````0$``!2M?__P0,```!!#@B%`D$.#(<#
M00X0A@1!#A2#!4,.0`/&`@H.%$'##A!!Q@X,0<<."$'%#@1!"T0```!$!```
MT[C__V8`````00X(AP)!#@R&`T$.$(,$0PX@`D\*#A!!PPX,0<8."$''#@1!
M"T4.$$'##@Q!Q@X(0<<.!````"P```",!```?(___PH"````00X(A0)"#05)
MAP.&!(,%`Y@!"L-!QD''0<4,!`1!"S@```"\!```P;C__V,`````10X(A0)!
M#@R'`T$.$(8$00X4@P5##D`"4PX40<,.$$'&#@Q!QPX(0<4.!!````#X!```
MZ+C__P4`````````'`````P%``#9N/__/@````!%#@B#`D,.('0."$'##@0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````/"F!`C2I@0(```````````````````````````!````
M`0````$```"7`0```0```*(!```!````K`$```$```#[`0```0```$`#```/
M````I@0```P`````H`0(#0```#S.!`@9````R"X%"!L````$````&@```,PN
M!0@<````!````/7^_V\,@@0(!0````R)!`@&````#(,$"`H```#=!```"P``
M`!`````5``````````,`````,`4(`@```/`!```4````$0```!<```!LCP0(
M$0```#R/!`@2````,````!,````(````_O__;ZR.!`C___]O`@```/#__V_J
MC00(````````````````````````````````````````````````````````
M`````````````.0N!0@``````````$:@!`A6H`0(9J`$"':@!`B&H`0(EJ`$
M"*:@!`BVH`0(QJ`$"-:@!`CFH`0(]J`$"`:A!`@6H00()J$$"#:A!`A&H00(
M5J$$"&:A!`AVH00(AJ$$"):A!`BFH00(MJ$$",:A!`C6H00(YJ$$"/:A!`@&
MH@0(%J($"":B!`@VH@0(1J($"%:B!`AFH@0(=J($"(:B!`B6H@0(IJ($"+:B
M!`C&H@0(UJ($".:B!`CVH@0(!J,$"!:C!`@FHP0(-J,$"$:C!`A6HP0(9J,$
M"':C!`B&HP0(EJ,$"*:C!`BVHP0(QJ,$"-:C!`CFHP0(]J,$"`:D!`@6I`0(
M``````````#______-($"$=#0SH@*%!,1"U,:6YU>"D@."XR+C`@,C`Q.#`W
M,C8@*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N
M9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````
M``````````````````````````````````````````````````L````!````
M`@```+2!!`BT`0``$P```````````````0`````````3````!P````(```#(
M@00(R`$``"````````````````0`````````(0````<````"````Z($$".@!
M```D```````````````$`````````#0```#V__]O`@````R"!`@,`@````$`
M``4`````````!`````0````^````"P````(````,@P0(#`,````&```&````
M`0````0````0````1@````,````"````#(D$"`P)``#=!``````````````!
M`````````$X```#___]O`@```.J-!`CJ#0``P`````4``````````@````(`
M``!;````_O__;P(```"LC@0(K`X``)`````&`````@````0`````````:@``
M``D````"````/(\$"#P/```P````!0`````````$````"````',````)````
M0@```&R/!`AL#P``\`$```4````7````!`````@```!\`````0````8`````
MH`0(`"```"0```````````````0`````````=P````$````&````,*`$"#`@
M``#P`P`````````````0````!````((````!````!@```""D!`@@)```&RH`
M````````````$`````````"(`````0````8````\S@0(/$X``!@`````````
M``````0`````````C@````$````"`````-`$"`!0```P/P`````````````$
M`````````)8````!`````@```#`/!0@PCP``Y```````````````!```````
M``"D`````0````(````4$`4(%)```"P%``````````````0`````````K@``
M``X````#````R"X%",B>```$```````````````$````!````+H````/````
M`P```,PN!0C,G@``!```````````````!`````0```#&`````0````,```#0
M+@4(T)X``!,```````````````@`````````TP````8````#````Y"X%".2>
M```8`0``!@`````````$````"````-P````!`````P```/PO!0C\GP``!```
M````````````!`````0```#A`````0````,`````,`4(`*````0!````````
M``````0````$````Z@````$````#````!#$%"`2A```0```````````````$
M`````````/`````(`````P```"`Q!0@4H0``5!``````````````(```````
M``#U`````0```#``````````%*$``"H```````````````$````!`````0``
E``,``````````````#ZA``#^```````````````!````````````
